@@ -9,10 +9,10 @@ import os.path
 import tempfile
 from collections.abc import Callable, Generator
 from pathlib import Path
-from typing import Iterable, Literal
+from typing import Literal
 
 import boto3
-from cloudpathlib import AnyPath, CloudPath, S3Client, S3Path
+from cloudpathlib import CloudPath, S3Client, S3Path
 from iker.common.utils.shutils import glob_match, listfile, path_depth
 from iker.common.utils.strutils import is_empty, trim_to_none
 from rich.progress import BarColumn, DownloadColumn, Progress, TaskID, TextColumn, TransferSpeedColumn
@@ -63,7 +63,7 @@ def s3_make_client(
     yield S3Client(boto3_session=session, endpoint_url=trim_to_none(endpoint_url))
 
 
-def s3_list_objects(client: S3Client, bucket: str, prefix: str, limit: int = None) -> Iterable[S3ObjectMeta]:
+def s3_list_objects(client: S3Client, bucket: str, prefix: str, limit: int = None) -> Generator[S3ObjectMeta]:
     """
     Lists all objects from the given S3 ``bucket`` and ``prefix``.
 
@@ -105,7 +105,7 @@ def s3_listfile(
     include_patterns: list[str] | None = None,
     exclude_patterns: list[str] | None = None,
     depth: int = 0,
-) -> Iterable[S3ObjectMeta]:
+) -> Generator[S3ObjectMeta]:
     """
     Lists all objects from the given S3 ``bucket`` and ``prefix``, filtered by patterns and directory depth.
 
@@ -323,7 +323,7 @@ class S3TransferCallbackClient(S3Client):
     def __init__(
         self,
         *args,
-        transfer_callback: Callable[[CloudPath, TransferDirection, TransferState, int], None],
+        transfer_callback: Callable[[Path | CloudPath, TransferDirection, TransferState, int], None],
         **kwargs,
     ):
         super().__init__(*args, **kwargs)
@@ -367,10 +367,12 @@ class S3TransferCallbackClient(S3Client):
         return cloud_path
 
 
-def s3_make_progress_callback(progress: Progress) -> Callable[[AnyPath, TransferDirection, TransferState, int], None]:
-    task_ids: dict[AnyPath, TaskID] = {}
+def s3_make_progress_callback(
+    progress: Progress,
+) -> Callable[[Path | CloudPath, TransferDirection, TransferState, int], None]:
+    task_ids: dict[Path | CloudPath, TaskID] = {}
 
-    def progress_callback(path: AnyPath, direction: TransferDirection, state: TransferState, bytes_sent: int):
+    def progress_callback(path: Path | CloudPath, direction: TransferDirection, state: TransferState, bytes_sent: int):
         if state == "start":
             size = path.stat().st_size
             task_ids[path] = progress.add_task(direction, total=size, filename=path.name)
